@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2009, 2020 Mountainminds GmbH & Co. KG and Contributors
+ * Copyright (c) 2009, 2024 Mountainminds GmbH & Co. KG and Contributors
  * This program and the accompanying materials are made available under
  * the terms of the Eclipse Public License 2.0 which is available at
  * http://www.eclipse.org/legal/epl-2.0
@@ -86,7 +86,7 @@ public class MergeMojo extends AbstractJacocoMojo {
 
 	private void load(final ExecFileLoader loader)
 			throws MojoExecutionException {
-		final FileSetManager fileSetManager = new FileSetManager(getLog());
+		final FileSetManager fileSetManager = new FileSetManager();
 		for (final FileSet fileSet : fileSets) {
 			for (final String includedFilename : fileSetManager
 					.getIncludedFiles(fileSet)) {
