@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2009, 2020 Mountainminds GmbH & Co. KG and Contributors
+ * Copyright (c) 2009, 2024 Mountainminds GmbH & Co. KG and Contributors
  * This program and the accompanying materials are made available under
  * the terms of the Eclipse Public License 2.0 which is available at
  * http://www.eclipse.org/legal/epl-2.0
@@ -14,6 +14,7 @@ package org.jacoco.core.test.validation.java5;
 
 import org.jacoco.core.test.validation.ValidationTestBase;
 import org.jacoco.core.test.validation.java5.targets.SyntheticTarget;
+import org.junit.Test;
 
 /**
  * Test of filtering of synthetic methods.
@@ -24,6 +25,7 @@ public class SyntheticTest extends ValidationTestBase {
 		super(SyntheticTarget.class);
 	}
 
+	@Test
 	public void test_method_count() {
 		assertMethodCount(5);
 	}
