@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2009, 2020 Mountainminds GmbH & Co. KG and Contributors
+ * Copyright (c) 2009, 2024 Mountainminds GmbH & Co. KG and Contributors
  * This program and the accompanying materials are made available under
  * the terms of the Eclipse Public License 2.0 which is available at
  * http://www.eclipse.org/legal/epl-2.0
@@ -24,4 +24,10 @@ public class KotlinDefaultMethodsTest extends ValidationTestBase {
 		super(KotlinDefaultMethodsTarget.class);
 	}
 
+	@Override
+	public void all_missed_instructions_should_have_line_number() {
+		// instructions without line numbers
+		// corresponding to non-executed default implementations
+	}
+
 }
