@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2009, 2020 Mountainminds GmbH & Co. KG and Contributors
+ * Copyright (c) 2009, 2024 Mountainminds GmbH & Co. KG and Contributors
  * This program and the accompanying materials are made available under
  * the terms of the Eclipse Public License 2.0 which is available at
  * http://www.eclipse.org/legal/epl-2.0
@@ -12,6 +12,7 @@
  *******************************************************************************/
 package org.jacoco.core;
 
+import static org.junit.Assert.assertEquals;
 import static org.junit.Assert.assertNotNull;
 
 import org.junit.Test;
@@ -26,6 +27,16 @@ public class JaCoCoTest {
 		assertNotNull(JaCoCo.VERSION);
 	}
 
+	@Test
+	public void testCOMMITID() {
+		assertNotNull(JaCoCo.COMMITID);
+	}
+
+	@Test
+	public void testCOMMITID_SHORT() {
+		assertEquals(7, JaCoCo.COMMITID_SHORT.length());
+	}
+
 	@Test
 	public void testHOMEURL() {
 		assertNotNull(JaCoCo.HOMEURL);
