@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2009, 2020 Mountainminds GmbH & Co. KG and Contributors
+ * Copyright (c) 2009, 2024 Mountainminds GmbH & Co. KG and Contributors
  * This program and the accompanying materials are made available under
  * the terms of the Eclipse Public License 2.0 which is available at
  * http://www.eclipse.org/legal/epl-2.0
@@ -33,6 +33,7 @@ import java.util.zip.ZipEntry;
 import java.util.zip.ZipInputStream;
 import java.util.zip.ZipOutputStream;
 
+import org.jacoco.core.JaCoCo;
 import org.jacoco.core.analysis.AnalyzerTest;
 import org.jacoco.core.internal.Pack200Streams;
 import org.jacoco.core.internal.data.CRC64;
@@ -99,7 +100,7 @@ public class InstrumenterTest {
 	@Test
 	public void should_not_modify_class_bytes_to_support_next_version()
 			throws Exception {
-		final byte[] originalBytes = createClass(Opcodes.V15 + 1);
+		final byte[] originalBytes = createClass(Opcodes.V22 + 1);
 		final byte[] bytes = new byte[originalBytes.length];
 		System.arraycopy(originalBytes, 0, bytes, 0, originalBytes.length);
 		final long expectedClassId = CRC64.classId(bytes);
@@ -122,14 +123,13 @@ public class InstrumenterTest {
 	 */
 	@Test
 	public void instrument_should_throw_exception_for_unsupported_class_file_version() {
-		final byte[] bytes = createClass(Opcodes.V15 + 2);
+		final byte[] bytes = createClass(Opcodes.V22 + 2);
 		try {
 			instrumenter.instrument(bytes, "UnsupportedVersion");
 			fail("exception expected");
 		} catch (final IOException e) {
-			assertEquals("Error while instrumenting UnsupportedVersion.",
-					e.getMessage());
-			assertEquals("Unsupported class file major version 61",
+			assertExceptionMessage("UnsupportedVersion", e);
+			assertEquals("Unsupported class file major version 68",
 					e.getCause().getMessage());
 		}
 	}
@@ -156,8 +156,7 @@ public class InstrumenterTest {
 			instrumenter.instrument(brokenclass, "Broken.class");
 			fail();
 		} catch (IOException e) {
-			assertEquals("Error while instrumenting Broken.class.",
-					e.getMessage());
+			assertExceptionMessage("Broken.class", e);
 		}
 	}
 
@@ -178,8 +177,7 @@ public class InstrumenterTest {
 			instrumenter.instrument(new BrokenInputStream(), "BrokenStream");
 			fail("exception expected");
 		} catch (IOException e) {
-			assertEquals("Error while instrumenting BrokenStream.",
-					e.getMessage());
+			assertExceptionMessage("BrokenStream", e);
 		}
 	}
 
@@ -194,8 +192,7 @@ public class InstrumenterTest {
 					new ByteArrayOutputStream(), "BrokenStream");
 			fail("exception expected");
 		} catch (IOException e) {
-			assertEquals("Error while instrumenting BrokenStream.",
-					e.getMessage());
+			assertExceptionMessage("BrokenStream", e);
 		}
 	}
 
@@ -224,15 +221,14 @@ public class InstrumenterTest {
 	 */
 	@Test
 	public void instrumentAll_should_throw_exception_for_unsupported_class_file_version() {
-		final byte[] bytes = createClass(Opcodes.V15 + 2);
+		final byte[] bytes = createClass(Opcodes.V22 + 2);
 		try {
 			instrumenter.instrumentAll(new ByteArrayInputStream(bytes),
 					new ByteArrayOutputStream(), "UnsupportedVersion");
 			fail("exception expected");
 		} catch (final IOException e) {
-			assertEquals("Error while instrumenting UnsupportedVersion.",
-					e.getMessage());
-			assertEquals("Unsupported class file major version 61",
+			assertExceptionMessage("UnsupportedVersion", e);
+			assertEquals("Unsupported class file major version 68",
 					e.getCause().getMessage());
 		}
 	}
@@ -297,7 +293,7 @@ public class InstrumenterTest {
 					new ByteArrayOutputStream(), "Broken");
 			fail("exception expected");
 		} catch (IOException e) {
-			assertEquals("Error while instrumenting Broken.", e.getMessage());
+			assertExceptionMessage("Broken", e);
 		}
 	}
 
@@ -324,7 +320,7 @@ public class InstrumenterTest {
 			instrumenter.instrumentAll(inputStream, new ByteArrayOutputStream(),
 					"Broken");
 		} catch (IOException e) {
-			assertEquals("Error while instrumenting Broken.", e.getMessage());
+			assertExceptionMessage("Broken", e);
 		}
 	}
 
@@ -346,7 +342,7 @@ public class InstrumenterTest {
 					new ByteArrayOutputStream(), "Test.zip");
 			fail("exception expected");
 		} catch (IOException e) {
-			assertEquals("Error while instrumenting Test.zip.", e.getMessage());
+			assertExceptionMessage("Test.zip", e);
 		}
 	}
 
@@ -371,9 +367,7 @@ public class InstrumenterTest {
 					new ByteArrayOutputStream(), "broken.zip");
 			fail("exception expected");
 		} catch (IOException e) {
-			assertEquals(
-					"Error while instrumenting broken.zip@brokenentry.txt.",
-					e.getMessage());
+			assertExceptionMessage("broken.zip@brokenentry.txt", e);
 		}
 	}
 
@@ -394,8 +388,7 @@ public class InstrumenterTest {
 					"test.zip");
 			fail();
 		} catch (IOException e) {
-			assertEquals("Error while instrumenting test.zip@Test.class.",
-					e.getMessage());
+			assertExceptionMessage("test.zip@Test.class", e);
 		}
 	}
 
@@ -412,7 +405,7 @@ public class InstrumenterTest {
 					new ByteArrayOutputStream(), "Test.gz");
 			fail("exception expected");
 		} catch (IOException e) {
-			assertEquals("Error while instrumenting Test.gz.", e.getMessage());
+			assertExceptionMessage("Test.gz", e);
 		}
 	}
 
@@ -462,8 +455,7 @@ public class InstrumenterTest {
 			instrumenter.instrumentAll(new ByteArrayInputStream(buffer),
 					new ByteArrayOutputStream(), "Test.pack200");
 		} catch (IOException e) {
-			assertEquals("Error while instrumenting Test.pack200.",
-					e.getMessage());
+			assertExceptionMessage("Test.pack200", e);
 		}
 	}
 
@@ -516,4 +508,10 @@ public class InstrumenterTest {
 		assertNull(zipin.getNextEntry());
 	}
 
+	private void assertExceptionMessage(String name, Exception ex) {
+		String expected = "Error while instrumenting " + name + " with JaCoCo "
+				+ JaCoCo.VERSION + "/" + JaCoCo.COMMITID_SHORT + ".";
+		assertEquals(expected, ex.getMessage());
+	}
+
 }
