@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2009, 2020 Mountainminds GmbH & Co. KG and Contributors
+ * Copyright (c) 2009, 2024 Mountainminds GmbH & Co. KG and Contributors
  * This program and the accompanying materials are made available under
  * the terms of the Eclipse Public License 2.0 which is available at
  * http://www.eclipse.org/legal/epl-2.0
@@ -56,10 +56,6 @@ public class MethodInstrumenterTest {
 		};
 	}
 
-	void sampleReturn() {
-		return;
-	}
-
 	@Test
 	public void testVisitProbe() {
 		instrumenter.visitProbe(33);
