@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2009, 2020 Mountainminds GmbH & Co. KG and Contributors
+ * Copyright (c) 2009, 2024 Mountainminds GmbH & Co. KG and Contributors
  * This program and the accompanying materials are made available under
  * the terms of the Eclipse Public License 2.0 which is available at
  * http://www.eclipse.org/legal/epl-2.0
@@ -17,6 +17,7 @@ import static org.junit.Assert.assertTrue;
 
 import java.io.IOException;
 import java.lang.reflect.Method;
+import java.util.ArrayList;
 import java.util.Arrays;
 
 import org.jacoco.core.analysis.Analyzer;
@@ -32,6 +33,7 @@ import org.jacoco.core.test.validation.Source.Line;
 import org.jacoco.core.test.validation.targets.Stubs;
 import org.junit.Before;
 import org.junit.Test;
+import org.junit.runners.model.MultipleFailureException;
 
 /**
  * Base class for validation tests. It executes the given class under code
@@ -41,9 +43,6 @@ public abstract class ValidationTestBase {
 
 	protected static final boolean isJDKCompiler = Compiler.DETECT.isJDK();
 
-	protected static final JavaVersion JAVA_VERSION = new JavaVersion(
-			System.getProperty("java.version"));
-
 	private static final String[] STATUS_NAME = new String[4];
 
 	{
@@ -71,6 +70,7 @@ public abstract class ValidationTestBase {
 
 	private ExecutionDataStore execute() throws Exception {
 		loader = new InstrumentingLoader(target);
+		loader.setDefaultAssertionStatus(true);
 		run(loader.loadClass(target.getName()));
 		return loader.collect();
 	}
@@ -105,14 +105,31 @@ public abstract class ValidationTestBase {
 	 * </pre>
 	 */
 	@Test
-	public void execute_assertions_in_comments() throws IOException {
+	public void execute_assertions_in_comments() throws Exception {
+		final ArrayList<Throwable> failedAssertions = new ArrayList<Throwable>();
 		for (Line line : source.getLines()) {
 			String exec = line.getComment();
 			if (exec != null) {
-				StatementParser.parse(exec, new StatementExecutor(this, line),
-						line.toString());
+				try {
+					StatementParser.parse(exec,
+							new StatementExecutor(this, line), line.toString());
+				} catch (final AssertionError e) {
+					failedAssertions.add(e);
+				}
 			}
 		}
+		MultipleFailureException.assertEmpty(failedAssertions);
+	}
+
+	/**
+	 * Source files for validation tests should contain the license header,
+	 * which can not contain executable lines, so this test allows to catch
+	 * cases when the compiler generates wrong line numbers.
+	 */
+	@Test
+	public void first_line_in_coverage_data_should_be_greater_than_one() {
+		assertTrue("First line in coverage data should be greater than one",
+				1 < source.getCoverage().getFirstLine());
 	}
 
 	@Test
