@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2009, 2020 Mountainminds GmbH & Co. KG and Contributors
+ * Copyright (c) 2009, 2024 Mountainminds GmbH & Co. KG and Contributors
  * This program and the accompanying materials are made available under
  * the terms of the Eclipse Public License 2.0 which is available at
  * http://www.eclipse.org/legal/epl-2.0
@@ -17,6 +17,7 @@ import java.util.Map;
 
 import org.objectweb.asm.Opcodes;
 import org.objectweb.asm.tree.AbstractInsnNode;
+import org.objectweb.asm.tree.FieldInsnNode;
 import org.objectweb.asm.tree.MethodInsnNode;
 import org.objectweb.asm.tree.MethodNode;
 import org.objectweb.asm.tree.TypeInsnNode;
@@ -76,6 +77,25 @@ abstract class AbstractMatcher {
 		cursor = null;
 	}
 
+	/**
+	 * Moves {@link #cursor} to next instruction if it is {@link FieldInsnNode}
+	 * with given opcode, owner, name and descriptor, otherwise sets it to
+	 * <code>null</code>.
+	 */
+	final void nextIsField(final int opcode, final String owner,
+			final String name, final String descriptor) {
+		nextIs(opcode);
+		if (cursor == null) {
+			return;
+		}
+		final FieldInsnNode f = (FieldInsnNode) cursor;
+		if (owner.equals(f.owner) && name.equals(f.name)
+				&& descriptor.equals(f.desc)) {
+			return;
+		}
+		cursor = null;
+	}
+
 	final void nextIsVar(final int opcode, final String name) {
 		nextIs(opcode);
 		if (cursor == null) {
